@@ -35,6 +35,13 @@ extends Horde_Crypt_Pgp_Backend
      */
     protected $_gnupg;
 
+    /**
+     * Whether the GnuPG version is 2.1 or later.
+     *
+     * @var boolean
+     */
+    protected $_gnupg21 = false;
+
     /**
      * Filename of the temporary private keyring.
      *
@@ -81,7 +88,8 @@ extends Horde_Crypt_Pgp_Backend
         /* GnuPG 2 requires specifying the pinentry-mode. */
         $result = $this->_callGpg(array('--version'), 'r');
         if (preg_match('/gpg \(GnuPG\) (\d+\.\d+\.\d+)/', $result->stdout, $version) &&
-            version_compare($version[1], '2.1.0', '>')) {
+            version_compare($version[1], '2.1.0', '>=')) {
+            $this->_gnupg21 = true;
             if (version_compare($version[1], '2.1.12', '>=')) {
                 $this->_gnupg[] = '--pinentry-mode loopback';
                 file_put_contents(
@@ -109,7 +117,7 @@ extends Horde_Crypt_Pgp_Backend
 
         $expire = empty($opts['expire'])
             ? 0
-            : date('Y-m-d', $opts['expire']);
+            : 'seconds=' . ($opts['expire'] - time());
 
         /* Create the config file necessary for GnuPG to run in batch mode. */
         /* TODO: Sanitize input, More user customizable? */
@@ -150,7 +158,9 @@ extends Horde_Crypt_Pgp_Backend
 
         /* If either key is empty, something went wrong. */
         if (empty($public_key) || empty($secret_key)) {
-            throw new Horde_Crypt_Exception(_("Cannot generate PGP keys"));
+            throw new Horde_Crypt_Exception(
+                Horde_Crypt_Translation::t("Cannot generate PGP keys")
+            );
         }
 
         return array(
@@ -177,8 +187,6 @@ extends Horde_Crypt_Pgp_Backend
         $key_idx = -1;
         $out = array();
 
-        $this2 = $this;
-
         $packetInfoHelper = function ($a) {
             return chr(hexdec($a[1]));
         };
@@ -312,12 +320,10 @@ extends Horde_Crypt_Pgp_Backend
                 }
 
                 if (isset($out[$key_idx]['signature'][$header]['sig_' . $sig_id]['created']) &&
-                    preg_match('/expires after (\d+y\d+d\d+h\d+m)\)$/', $line, $matches)) {
-                    $expires = $matches[1];
-                    preg_match('/^(\d+)y(\d+)d(\d+)h(\d+)m$/', $expires, $matches);
+                    preg_match('/expires after (?:(?:(\d+)y)?(\d+)d)?(\d+)h(\d+)m\)$/', $line, $matches)) {
                     list(, $years, $days, $hours, $minutes) = $matches;
                     $out[$key_idx]['signature'][$header]['sig_' . $sig_id]['expires'] =
-                        strtotime('+ ' . $years . ' years + ' . $days . ' days + ' . $hours . ' hours + ' . $minutes . ' minutes', $out[$key_idx]['signature'][$header]['sig_' . $sig_id]['created']);
+                        strtotime('+ ' . (int)$years . ' years + ' . (int)$days . ' days + ' . $hours . ' hours + ' . $minutes . ' minutes', $out[$key_idx]['signature'][$header]['sig_' . $sig_id]['created']);
                     continue;
                 }
 
@@ -374,7 +380,9 @@ extends Horde_Crypt_Pgp_Backend
             return substr($matches[1], -8);
         }
 
-        throw new Horde_Crypt_Exception(_("Cannot read PGP key ID"));
+        throw new Horde_Crypt_Exception(
+            Horde_Crypt_Translation::t("Cannot read PGP key ID")
+        );
     }
 
     /**
